@@ -99,7 +99,11 @@ def 取代码(欲取字符代码的文本: str) -> int:
 # 操作系统需求： Windows、Linux
 # 找不到返回-1
 def 寻找文本(被搜寻的文本: str, 欲寻找的文本: str, 起始搜寻位置=None, 结束的位置=None) -> int:
-    return 被搜寻的文本.find(欲寻找的文本, 起始搜寻位置, 结束的位置)
+    try:
+        result = 被搜寻的文本.find(欲寻找的文本, 起始搜寻位置, 结束的位置)
+    except:
+        result = -1
+    return result
 
 
 def 倒找文本(被搜寻的文本: str, 欲寻找的文本: str, 起始搜寻位置=None, 结束的位置=None) -> int:
@@ -186,6 +190,8 @@ def 删全部空(欲删除空格的文本: str) -> str:
 #
 # 操作系统需求： Windows、Linux
 def 子文本替换(欲被替换的文本: str, 欲被替换的子文本: str, 用作替换的子文本: str, 替换进行的次数=-1) -> str:
+    if (欲被替换的子文本 == ""):
+        return 欲被替换的文本
     return 欲被替换的文本.replace(欲被替换的子文本, 用作替换的子文本, 替换进行的次数)
 
 
