@@ -125,8 +125,11 @@ class 日期时间:
         return self.到文本()
 
 
-def 取现行时间戳():
-    return round(time.time())
+def 取现行时间戳(位数=13):
+    if 位数==10:
+        return int(time.time())
+    else:
+        return int(round(time.time() * 1000))
 
 
 def 日期到时间戳(str="now"):
@@ -136,7 +139,43 @@ def 日期到时间戳(str="now"):
 def 取现行时间():
     t = 日期时间()
     return t
+def 取现行时间2(格式,自定义=False):
+    """
+    自定义  %Y-%m-%d %H:%M:%S    (yyyy-MM-dd HH:mm:ss)这种格式不可以
+    格式1 = 2020-10-09 22:11:52   格式2 = 2020-10-09 格式3= 22:13:37 格式4= 2020年10月17日18时27分40秒
 
+    %a  # 本地(local) 简化星期名称
+    %A  # 本地完整星期名称
+    %b  # 本地简化月份名称
+    %B  # 本地完整月份名称
+    %c  # 本地相应的日期和时间表示
+    %d  # 一个月中的第几天（01-31）
+    %H  # 一天中的第几个小时（24小时制00-23）
+    %I  # 第几个小时（12小时制01-12）
+    %j  # 一年中的第几天（001-366）
+    %m  # 月份（01-12）
+    %M  # 分钟数（00-59）
+    %p  # 本地am或pm的相应符
+    %S  # 秒（01-60）
+    %U  # 一年中的星期数。（00-53 星期天是一个星期的开始）第一个星期天之前的所有天数都放在第0周
+    %w  # 一个星期中的第几天（0-6 0是星期天）
+    %W  # 和%U基本相同，不同的是%W以星期一为一个星期的开始
+    %x  # 本地相应日期
+    %X  # 本地相应时间
+    %y  # 去掉世纪的年份（00-99）
+    %Y  # 完整的年份
+    %z  # 时区的名字
+    """
+    if 自定义:
+        return time.strftime(格式, time.localtime())#2020-10-09 22:11:52
+    if 格式==1:
+        return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())#2020-10-09 22:11:52
+    elif 格式==2:
+        return time.strftime("%Y-%m-%d", time.localtime())#2020-10-09
+    elif 格式==3:
+        return time.strftime("%H:%M:%S", time.localtime())#22:13:37
+    elif 格式==4:
+        return time.strftime("%Y{}%m{}%d{}%H{}%M{}%S{}", time.localtime()).format('年','月','日','时','分','秒')#2020年10月17日18时27分40秒
 
 def now():
     t = 日期时间()
